from PIL import Image
from PIL.ExifTags import TAGS

def extract_metadata(image_path):
    try:
        img = Image.open(image_path)
        exif_data = img._getexif()
        if not exif_data:
            return {"result": "No EXIF metadata found."}
        return {TAGS.get(k, k): v for k, v in exif_data.items()}
    except Exception as e:
        return {"error": str(e)}

# Example usage:
# print(extract_metadata("test.jpg"))


import requests

def check_username(username):
    platforms = {
        "Twitter": f"https://twitter.com/{username}",
        "GitHub": f"https://github.com/{username}",
        "Instagram": f"https://instagram.com/{username}",
        "Facebook": f"https://facebook.com/{username}",
        "Reddit": f"https://www.reddit.com/user/{username}",
        "YouTube": f"https://www.youtube.com/{username}",
        "Pinterest": f"https://www.pinterest.com/{username}/",
        "Tumblr": f"https://{username}.tumblr.com/",
        "Flickr": f"https://www.flickr.com/people/{username}/",
        "Vimeo": f"https://vimeo.com/{username}",
        "SoundCloud": f"https://soundcloud.com/{username}",
        "Medium": f"https://medium.com/@{username}",
        "DeviantArt": f"https://{username}.deviantart.com/",
        "Twitch": f"https://www.twitch.tv/{username}",
        "Steam": f"https://steamcommunity.com/id/{username}",
        "GitLab": f"https://gitlab.com/{username}",
        "Bitbucket": f"https://bitbucket.org/{username}/",
        "Keybase": f"https://keybase.io/{username}",
        "About.me": f"https://about.me/{username}",
        "ProductHunt": f"https://www.producthunt.com/@{username}",
        "500px": f"https://500px.com/{username}",
        "Behance": f"https://www.behance.net/{username}",
        "VK": f"https://vk.com/{username}",
        "OK.ru": f"https://ok.ru/{username}",
        "Dribbble": f"https://dribbble.com/{username}",
    }
    results = {}
    for name, url in platforms.items():
        try:
            resp = requests.get(url, timeout=5)
            results[name] = resp.status_code == 200
        except Exception:
            results[name] = False
    return results

# Example usage:
# print(check_username("jack"))


import socket

def port_scan_cli(host, ports=None):
    if ports is None:
        ports = [21, 22, 23, 25, 53, 80, 110, 143, 443, 3306, 8080]
    open_ports = []
    for port in ports:
        try:
            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            sock.settimeout(1)
            result = sock.connect_ex((host, port))
            if result == 0:
                open_ports.append(port)
            sock.close()
        except Exception:
            continue
    return open_ports


import requests

def reverse_ip_lookup(ip):
    try:
        resp = requests.get(f"https://api.hackertarget.com/reverseiplookup/?q={ip}", timeout=10)
        if resp.status_code == 200:
            return resp.text.splitlines()
        else:
            return {"error": f"Status {resp.status_code}"}
    except Exception as e:
        return {"error": str(e)}

# Example usage:
# print(reverse_ip_lookup("8.8.8.8"))


import requests
import time
import sys
import threading

# ANSI color codes for terminal output
GREEN = "\033[92m"
RED = "\033[91m"
YELLOW = "\033[93m"
CYAN = "\033[96m"
RESET = "\033[0m"
WHITE = "\033[97m"

def current_time_hour():
    return time.strftime("%H:%M:%S")

# Spinner implementation
class Spinner:
    def __init__(self, message="Scanning..."):
        self.spinner = ['|', '/', '-', '\\']
        self.idx = 0
        self.running = False
        self.thread = None
        self.message = message

    def spin(self):
        while self.running:
            sys.stdout.write(f"\r{self.message} {self.spinner[self.idx % len(self.spinner)]}")
            sys.stdout.flush()
            self.idx += 1
            time.sleep(0.1)
        sys.stdout.write('\r' + ' ' * (len(self.message) + 4) + '\r')  # Clear line

    def start(self):
        self.running = True
        self.thread = threading.Thread(target=self.spin)
        self.thread.start()

    def stop(self):
        self.running = False
        if self.thread:
            self.thread.join()

def scan_sql_injection(url, report):
    payloads = [
        "'", '"', "''", "' OR '1'='1'", "' OR '1'='1' --", "' OR '1'='1' /*", "' OR 1=1 --", "/1000",
        "' OR 1=1 /*", "' OR 'a'='a", "' OR 'a'='a' --", "' OR 'a'='a' /*", "' OR ''='", "admin'--", "admin' /*",
        "' OR 1=1#", "' OR '1'='1' (", "') OR ('1'='1", "'; EXEC xp_cmdshell('dir'); --", "' UNION SELECT NULL, NULL, NULL --", 
        "' OR 1=1 --", "' OR '1'='1' --", "' OR '1'='1' #", "' OR '1'='1'/*", "' OR '1'='1'--", "' OR 1=1#", "' OR 1=1/*", 
        "' OR 'a'='a'#", "' OR 'a'='a'/*", "' OR ''=''", "' OR '1'='1'--", "admin' --", "admin' #", "' OR 1=1--", "' OR 1=1/*", 
        "' OR 'a'='a'--", "' OR ''=''", "' OR 'x'='x'", "' OR 'x'='x'--", "' OR 'x'='x'/*", "' OR 1=1#", "' OR 1=1--", 
        "' OR 1=1/*", "' OR '1'='1'/*", "' OR '1'='1'--", "' OR '1'='1'#", "' OR '1'='1'/*"
    ]
    indicators = [
        "SQL syntax", "SQL error", "MySQL", "mysql", "MySQLYou",
        "Unclosed quotation mark", "SQLSTATE", "syntax error", "ORA-", 
        "SQLite", "PostgreSQL", "Truncated incorrect", "Division by zero",
        "You have an error in your SQL syntax", "Incorrect syntax near", 
        "SQL command not properly ended", "sql", "Sql", "Warning", "Error"
    ]
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36"
    }
    found = []
    for payload in payloads:
        try:
            resp = requests.get(url, params={"id": payload}, timeout=4, headers=headers)
            for indicator in indicators:
                if indicator.lower() in resp.text.lower():
                    found.append(f"Payload: {payload} | Indicator: {indicator}")
        except Exception:
            continue
    report['sql'] = found

def scan_xss(url, report):
    payloads = [
        "<script>alert('Found using Sentient(a summer of hacking Project by x0as (Huzaifa)')</script>",
        "<img src=x onerror=alert('Found using Sentient(a summer of hacking Project by x0as (Huzaifa)')>",
        "<svg/onload=alert('Found using Sentient(a summer of hacking Project by x0as (Huzaifa)')>"
    ]
    indicators = [
        "<script>",
        "alert('Found using Sentient(a summer of hacking Project by x0as (Huzaifa)')",
        "onerror=",
        "<svg",
        "javascript:"
    ]
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36"
    }
    found = []
    for payload in payloads:
        try:
            resp = requests.get(url, params={"q": payload}, timeout=4, headers=headers)
            for indicator in indicators:
                if indicator in resp.text:
                    found.append(f"Payload: {payload} | Indicator: {indicator}")
        except Exception:
            continue
    report['xss'] = found

def scan_interesting_paths(url, report):
    paths = [
        "admin", "admin/", "admin/index.php", "admin/login.php", "admin/config.php",
        "backup", "backup/", "backup/db.sql", "backup/config.tar.gz", "backup/backup.sql",
        "private", "private/", "private/.env", "private/config.php", "private/secret.txt",
        "uploads", "uploads/", "uploads/file.txt", "uploads/image.jpg", "uploads/backup.zip",
        "api", "api/", "api/v1/", "api/v1/users", "api/v1/status",
        "logs", "logs/", "logs/error.log", "logs/access.log", "logs/debug.log",
        "cache", "cache/", "cache/temp/", "cache/session/", "cache/data/",
        "server-status", "server-status/", "server-status/index.html",
        "dashboard", "dashboard/", "dashboard/index.html", "dashboard/admin.php", "dashboard/settings.php"
    ]
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36"
    }
    found = []
    for path in paths:
        try:
            full_url = url.rstrip("/") + "/" + path
            resp = requests.get(full_url, timeout=4, headers=headers)
            if resp.status_code == 200:
                found.append(path)
        except Exception:
            continue
    report['paths'] = found

def scan_sensitive_files(url, report):
    files = [
        "etc/passwd", "etc/password", "etc/shadow", "etc/group", "etc/hosts", "etc/hostname",
        "var/log/auth.log", "var/log/syslog", "var/log/messages", "var/log/nginx/access.log",
        "root/.bash_history", "home/user/.bash_history", "www/html/wp-config.php", "proc/self/environ",
        "opt/lampp/phpmyadmin/config.inc.php", "boot/grub/menu.lst", "proc/net/tcp"
    ]
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/124.0.0.0 Safari/537.36"
    }
    found = []
    for file in files:
        try:
            full_url = url.rstrip("/") + "/" + file
            resp = requests.get(full_url, timeout=4, headers=headers)
            if resp.status_code == 200 and len(resp.text) > 10:
                found.append(file)
        except Exception:
            continue
    report['files'] = found

def website_vulnerability_scan_cli_with_url(url, return_results=False):
    print(f"{CYAN}Website Vulnerability Scanner{RESET}")
    if not url.startswith("http"):
        url = "https://" + url
    print(f"{CYAN}[{current_time_hour()}]{RESET} {YELLOW}Initiating scan. Please wait...{RESET}")

    report = {}

    spinner = Spinner("Scanning website for vulnerabilities")
    spinner.start()

    try:
        scan_sql_injection(url, report)
        scan_xss(url, report)
        scan_interesting_paths(url, report)
        scan_sensitive_files(url, report)
    except KeyboardInterrupt:
        spinner.stop()
        print(f"{RED}\nScan interrupted by user.{RESET}")
        return

    spinner.stop()

    print(f"{CYAN}[{current_time_hour()}]{RESET} {GREEN}Scan complete.{RESET}\n")

    print(f"{CYAN}--- Vulnerability Scan Results for {url} ---{RESET}")
    print(f"{YELLOW}SQL Injection vulnerabilities found:{RESET}")
    if report['sql']:
        for item in report['sql']:
            print(f"  {GREEN}{item}{RESET}")
    else:
        print(f"  {RED}None{RESET}")

    print(f"{YELLOW}Cross-site scripting (XSS) vulnerabilities found:{RESET}")
    if report['xss']:
        for item in report['xss']:
            print(f"  {GREEN}{item}{RESET}")
    else:
        print(f"  {RED}None{RESET}")

    print(f"{YELLOW}Interesting paths found:{RESET}")
    if report['paths']:
        for item in report['paths']:
            print(f"  {GREEN}{item}{RESET}")
    else:
        print(f"  {RED}None{RESET}")

    print(f"{YELLOW}Sensitive files found:{RESET}")
    if report['files']:
        for item in report['files']:
            print(f"  {GREEN}{item}{RESET}")
    else:
        print(f"  {RED}None{RESET}")

    print(f"{CYAN}Scan finished. Returning to Sentient CLI...{RESET}")

    if return_results:
        return report

# For standalone usage
def website_vulnerability_scan_cli():
    url = input(f"{YELLOW}Enter website URL (with http/https): {RESET}").strip()
    website_vulnerability_scan_cli_with_url(url)

if __name__ == "__main__":
    website_vulnerability_scan_cli()



import hashlib

def identify_hash(hash_str):
    hash_types = {
        32: "MD5",
        40: "SHA1",
        56: "SHA224",
        64: "SHA256",
        96: "SHA384",
        128: "SHA512"
    }
    return hash_types.get(len(hash_str), "Unknown")

def crack_hash(hash_str, wordlist=None):
    if wordlist is None:
        wordlist = ["password", "123456", "admin", "letmein", "qwerty", "sentient"]
    hash_type = identify_hash(hash_str)
    for word in wordlist:
        if hash_type == "MD5":
            if hashlib.md5(word.encode()).hexdigest() == hash_str:
                return word
        elif hash_type == "SHA1":
            if hashlib.sha1(word.encode()).hexdigest() == hash_str:
                return word
        elif hash_type == "SHA256":
            if hashlib.sha256(word.encode()).hexdigest() == hash_str:
                return word
        elif hash_type == "SHA512":
            if hashlib.sha512(word.encode()).hexdigest() == hash_str:
                return word
    return None


import ssl
import socket

def check_ssl(domain):
    ctx = ssl.create_default_context()
    try:
        with ctx.wrap_socket(socket.socket(), server_hostname=domain) as s:
            s.settimeout(5)
            s.connect((domain, 443))
            cert = s.getpeercert()
            return {
                "subject": dict(x[0] for x in cert['subject']),
                "issuer": dict(x[0] for x in cert['issuer']),
                "valid_from": cert['notBefore'],
                "valid_to": cert['notAfter'],
                "serial_number": cert['serialNumber'],
            }
    except Exception as e:
        return {"error": str(e)}



import requests

def send_traffic(target_url, count=1):
    """
    Sends a number of HTTP GET requests to the target URL.
    Returns a summary string.
    """
    success = 0
    fail = 0
    for _ in range(int(count)):
        try:
            response = requests.get(target_url, timeout=3)
            if response.status_code == 200:
                success += 1
            else:
                fail += 1
        except Exception:
            fail += 1
    return f"Traffic sent: {success} successful, {fail} failed requests to {target_url}"


from selenium import webdriver
from selenium.webdriver.chrome.options import Options
import time
import threading
import sys

def spinner(stop_event):
    spinner_chars = ['|', '/', '-', '\\']
    idx = 0
    while not stop_event.is_set():
        sys.stdout.write(f"\rImitating real traffic... {spinner_chars[idx % len(spinner_chars)]}")
        sys.stdout.flush()
        idx += 1
        time.sleep(0.1)
    sys.stdout.write("\r" + " " * 40 + "\r")  # Clear line

def imitate_real_traffic(target_url, count=1, wait_time=3):
    """
    Opens the target URL in a real browser window using Selenium, simulating real user visits.
    count: Number of times to open the URL.
    wait_time: Seconds to wait on the page before closing.
    """
    success = 0
    fail = 0

    chrome_options = Options()
    chrome_options.add_argument("--headless")
    chrome_options.add_argument("--disable-gpu")
    chrome_options.add_argument("--no-sandbox")
    chrome_options.add_argument("--window-size=1920,1080")
    chrome_options.add_argument("--disable-blink-features=AutomationControlled")
    chrome_options.add_argument("--disable-logging")
    chrome_options.add_argument("--log-level=3")
    chrome_options.add_experimental_option('excludeSwitches', ['enable-logging'])

    stop_event = threading.Event()
    t = threading.Thread(target=spinner, args=(stop_event,))
    t.start()

    try:
        driver = webdriver.Chrome(options=chrome_options)
    except Exception:
        stop_event.set()
        t.join()
        return "Could not start browser for real traffic imitation. Please check your ChromeDriver installation."

    for _ in range(int(count)):
        try:
            driver.get(target_url)
            time.sleep(wait_time)
            success += 1
        except Exception:
            fail += 1
        time.sleep(0.2)  # Give spinner time to update

    driver.quit()
    stop_event.set()
    t.join()
    return f"Imitated real traffic: {success} successful, {fail} failed visits to {target_url}"


def check_subdomain_takeover(domain):
    # Placeholder: Real logic would check CNAMEs, HTTP responses, etc.
    return f"Checked {domain} for subdomain takeover (demo only)."

# Example usage:
# print(check_subdomain_takeover("test.example.com"))


import os

def analyze_pdf(filepath):
    # Placeholder: Add real PDF malware/macro analysis here
    if not os.path.isfile(filepath):
        return {"error": "File not found"}
    return {"result": f"Scanned {filepath}. No malware or macros detected (demo)."}

# Example usage:
# print(analyze_pdf("test.pdf"))


import phonenumbers
from phonenumbers import geocoder, carrier, timezone

def phone_lookup_cli(phone_number):
    try:
        parsed_number = phonenumbers.parse(phone_number, None)
        if phonenumbers.is_valid_number(parsed_number):
            status = "Valid"
        else:
            status = "Invalid"

        if phone_number.startswith("+"):
            country_code = "+" + phone_number[1:3]
        else:
            country_code = "None"

        try:
            operator = carrier.name_for_number(parsed_number, "en")
        except Exception:
            operator = "None"

        try:
            type_number = "Mobile" if phonenumbers.number_type(parsed_number) == phonenumbers.PhoneNumberType.MOBILE else "Fixed"
        except Exception:
            type_number = "None"

        try:
            timezones = timezone.time_zones_for_number(parsed_number)
            timezone_info = timezones[0] if timezones else "None"
        except Exception:
            timezone_info = "None"

        try:
            country = phonenumbers.region_code_for_number(parsed_number)
        except Exception:
            country = "None"

        try:
            region = geocoder.description_for_number(parsed_number, "en")
        except Exception:
            region = "None"

        try:
            formatted_number = phonenumbers.format_number(parsed_number, phonenumbers.PhoneNumberFormat.NATIONAL)
        except Exception:
            formatted_number = "None"

        result = {
            "Phone": phone_number,
            "Formatted": formatted_number,
            "Status": status,
            "Country Code": country_code,
            "Country": country,
            "Region": region,
            "Timezone": timezone_info,
            "Operator": operator,
            "Type Number": type_number,
        }
        return result
    except Exception:
        return {"Error": "Invalid Format!"}

if __name__ == "__main__":
    phone = input("Phone Number -> ")
    info = phone_lookup_cli(phone)
    print("\n[~] Information Recovery..\n")
    for k, v in info.items():
        print(f"[+] {k:<12}: {v}")


import requests

def search_cve(product):
    url = f"https://cve.circl.lu/api/search/{product}"
    try:
        resp = requests.get(url, timeout=10)
        return resp.json()
    except Exception as e:
        return {"error": str(e)}
    
    # Example usage:
    # print(search_cve("apache"))


import requests

def dir_bruteforce(url, wordlist=None):
    if wordlist is None:
        wordlist = ["admin", "login", "dashboard", "uploads",]
    found = []
    for words in wordlist:
        test_url = url.rstrip("/") + "/" + words
        try:
            resp = requests.get(test_url, timeout=3)
            if resp.status_code == 200:
                found.append(test_url)
        except Exception:
            continue
    return found


from setuptools import setup, find_packages
import pathlib

HERE = pathlib.Path(__file__).parent
README = (HERE / "README.md").read_text()

setup(
    name="sentient-ai",
    version="1.0.3",
    author="x0as",
    author_email="muhammadhuzaifakhalidaziz@gmail.com",
    description="AI-powered cybersecurity and automation toolkit",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/x0as/Sentient",
    project_urls={
        "Bug Reports": "https://github.com/x0as/Sentient/issues",
        "Source": "https://github.com/x0as/Sentient",
    },
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "requests>=2.25.1",
        "google-generativeai>=0.3.0",
        "pymongo>=4.0.0",
    "beautifulsoup4>=4.9.3",
    "phonenumbers>=8.12.0",
    "Pillow>=8.0.0",
    "selenium>=3.141.0",
    "dnspython>=2.1.0",
        "tabulate>=0.8.9",
        "fuzzywuzzy>=0.18.0",
        "python-Levenshtein>=0.12.2",
        "dnspython>=2.1.0",
        "python-whois>=0.7.3",
        "cryptography>=3.4.8",
        "scapy>=2.4.5",
        "colorama>=0.4.4",
        "google-search-results>=2.4.0",
        "fastapi>=0.68.0",
        "uvicorn>=0.15.0",
        "whois>=0.9.13",
    ],
    extras_require={
        "dev": [
            "pytest>=6.0",
            "black>=21.0",
            "flake8>=3.8",
            "mypy>=0.812",
        ],
    },
    entry_points={
        "console_scripts": [
            "sentient=sentient.main:main",
        ],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Information Technology",
        "Topic :: Security",
        "License :: Other/Proprietary License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
    keywords="cybersecurity, automation, ai, hacking, penetration-testing, osint",
)
